/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.ui.forms.widgets.FormToolkit;
import org.eclipse.wb.swt.ResourceManager;

/**
 * This dialog offers a common dialog to show multi-root tree structures and
 * allows user to select one item in the tree. It also offers interface to edit
 * the tree on the fly.
 * 
 * @author mou
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 462DB0F8E313BA5B1E43BA25EEE098D2
 */
public class ElementTreeSingleSelectDialogGUI extends Composite {

	/** GUI Factory */
	private final FormToolkit formToolkit = new FormToolkit(
			Display.getDefault());

	/** the main tree viewer */
	private TreeViewer elementTreeViewer;
	private Button createButton;
	private Button deleteButton;
	private Button editButton;
	private Composite lefttoolbar;

	/**
	 * Default Constructor for GUI builder.
	 */
	public ElementTreeSingleSelectDialogGUI(Composite parent, int style) {
		super(parent, style);

		GridLayout gl_container = new GridLayout(3, false);
		gl_container.verticalSpacing = 2;
		gl_container.marginRight = 5;
		gl_container.marginLeft = 5;
		gl_container.marginBottom = 5;
		gl_container.marginTop = 5;
		gl_container.marginWidth = 0;
		gl_container.marginHeight = 0;
		setLayout(gl_container);

		lefttoolbar = new Composite(this, SWT.NONE);
		lefttoolbar.setLayoutData(new GridData(SWT.CENTER, SWT.FILL, false,
				true, 1, 1));
		GridLayout gl_lefttoolbar = new GridLayout(1, false);
		gl_lefttoolbar.verticalSpacing = 2;
		gl_lefttoolbar.horizontalSpacing = 2;
		gl_lefttoolbar.marginHeight = 0;
		gl_lefttoolbar.marginWidth = 0;
		lefttoolbar.setLayout(gl_lefttoolbar);

		createButton = new Button(lefttoolbar, SWT.NONE);
		createButton.setImage(ResourceManager.getPluginImage("org.eclipse.ui",
				"/icons/full/obj16/add_obj.gif"));
		formToolkit.adapt(createButton, true, true);

		deleteButton = new Button(lefttoolbar, SWT.NONE);
		deleteButton.setImage(ResourceManager.getPluginImage("org.eclipse.ui",
				"/icons/full/obj16/delete_obj.gif"));
		formToolkit.adapt(deleteButton, true, true);

		editButton = new Button(lefttoolbar, SWT.NONE);
		editButton.setImage(ResourceManager.getPluginImage("org.eclipse.ui",
				"/icons/full/etool16/editor_area.gif"));
		formToolkit.adapt(editButton, true, true);

		elementTreeViewer = new TreeViewer(this, SWT.BORDER);
		Tree elementTree = elementTreeViewer.getTree();
		elementTree.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true,
				1, 1));

		Composite toolbarbox = new Composite(this, SWT.NONE);
		GridLayout gl_toolbarbox = new GridLayout(1, false);
		gl_toolbarbox.verticalSpacing = 2;
		gl_toolbarbox.horizontalSpacing = 2;
		gl_toolbarbox.marginHeight = 0;
		gl_toolbarbox.marginWidth = 0;
		toolbarbox.setLayout(gl_toolbarbox);
		toolbarbox.setLayoutData(new GridData(SWT.CENTER, SWT.CENTER, false,
				true, 1, 1));
	}

	/** Get the element tree viewer */
	public TreeViewer getElementTreeViewer() {
		return elementTreeViewer;
	}

	/** Get the create button */
	public Button getCreateButton() {
		return createButton;
	}

	/** Get the delete button */
	public Button getDeleteButton() {
		return deleteButton;
	}

	/** Get the edit button */
	public Button getEditButton() {
		return editButton;
	}

	/** Get the tool bar */
	public Composite getLeftToolBar() {
		return lefttoolbar;
	}
}